import type { OpenId4VciCreateCredentialResponseOptions, OpenId4VciCreateCredentialOfferOptions, OpenId4VciCreateIssuerOptions } from './OpenId4VcIssuerServiceOptions';
import type { OpenId4VcIssuerRecordProps } from './repository';
import type { OpenId4VciCredentialOfferPayload } from '../shared';
import { AgentContext } from '@credo-ts/core';
import { OpenId4VcIssuerModuleConfig } from './OpenId4VcIssuerModuleConfig';
import { OpenId4VcIssuerService } from './OpenId4VcIssuerService';
/**
 * @public
 * This class represents the API for interacting with the OpenID4VC Issuer service.
 * It provides methods for creating a credential offer, creating a response to a credential issuance request,
 * and retrieving a credential offer from a URI.
 */
export declare class OpenId4VcIssuerApi {
    readonly config: OpenId4VcIssuerModuleConfig;
    private agentContext;
    private openId4VcIssuerService;
    constructor(config: OpenId4VcIssuerModuleConfig, agentContext: AgentContext, openId4VcIssuerService: OpenId4VcIssuerService);
    getAllIssuers(): Promise<import("./repository").OpenId4VcIssuerRecord[]>;
    getByIssuerId(issuerId: string): Promise<import("./repository").OpenId4VcIssuerRecord>;
    /**
     * Creates an issuer and stores the corresponding issuer metadata. Multiple issuers can be created, to allow different sets of
     * credentials to be issued with each issuer.
     */
    createIssuer(options: OpenId4VciCreateIssuerOptions): Promise<import("./repository").OpenId4VcIssuerRecord>;
    /**
     * Rotate the key used for signing access tokens for the issuer with the given issuerId.
     */
    rotateAccessTokenSigningKey(issuerId: string): Promise<void>;
    getIssuerMetadata(issuerId: string): Promise<import("./OpenId4VcIssuerServiceOptions").OpenId4VcIssuerMetadata>;
    updateIssuerMetadata(options: Pick<OpenId4VcIssuerRecordProps, 'issuerId' | 'credentialsSupported' | 'display'>): Promise<void>;
    /**
     * Creates a credential offer. Either the preAuthorizedCodeFlowConfig or the authorizationCodeFlowConfig must be provided.
     *
     * @returns Object containing the payload of the credential offer and the credential offer request, which can be sent to the wallet.
     */
    createCredentialOffer(options: OpenId4VciCreateCredentialOfferOptions & {
        issuerId: string;
    }): Promise<{
        credentialOfferPayload: import("@sphereon/oid4vci-common").CredentialOfferPayloadV1_0_11;
        credentialOffer: string;
    }>;
    /**
     * This function retrieves the credential offer referenced by the given URI.
     * Retrieving a credential offer from a URI is possible after a credential offer was created with
     * @see createCredentialOffer and the credentialOfferUri option.
     *
     * @throws if no credential offer can found for the given URI.
     * @param uri - The URI referencing the credential offer.
     * @returns The credential offer payload associated with the given URI.
     */
    getCredentialOfferFromUri(uri: string): Promise<OpenId4VciCredentialOfferPayload>;
    /**
     * This function creates a response which can be send to the holder after receiving a credential issuance request.
     *
     * @param options.credentialRequest - The credential request, for which to create a response.
     * @param options.credential - The credential to be issued.
     * @param options.verificationMethod - The verification method used for signing the credential.
     */
    createCredentialResponse(options: OpenId4VciCreateCredentialResponseOptions & {
        issuerId: string;
    }): Promise<import("@sphereon/oid4vci-common").CredentialResponse>;
}
